#[component]Expand description
Attribute macro for defining components.
This macro transforms a function into a component that can be used in RSX expressions.
#[component]Attribute macro for defining components.
This macro transforms a function into a component that can be used in RSX expressions.